@@ -863,10 +863,16 @@ void MDWSlider::volumeChange( int )
 //  {
 //    kDebug(67100) << "headphone bug";
 //  }
-	m_waitForSoundSetComplete ++;
-	volumeValues.push_back(m_slidersPlayback.first()->value());
-	if (m_slidersPlayback.count() > 0) volumeChangeInternal(m_mixdevice->playbackVolume(), m_slidersPlayback);
-	if (m_slidersCapture.count()  > 0) volumeChangeInternal(m_mixdevice->captureVolume(), m_slidersCapture);
+	if (!m_slidersPlayback.isEmpty())
+	{
+		m_waitForSoundSetComplete ++;
+		volumeValues.push_back(m_slidersPlayback.first()->value());
+		volumeChangeInternal(m_mixdevice->playbackVolume(), m_slidersPlayback);
+	}
+	if (!m_slidersCapture.isEmpty())
+	{
+		volumeChangeInternal(m_mixdevice->captureVolume(), m_slidersCapture);
+	}
 
 	bool oldViewBlockSignalState = m_view->blockSignals(true);
 	m_mixdevice->mixer()->commitVolumeChange(m_mixdevice);
@@ -1143,7 +1149,7 @@ void MDWSlider::updateAccesability()
 #endif
 
 
-void MDWSlider::showContextMenu()
+void MDWSlider::showContextMenu( const QPoint& pos )
 {
 	if( m_view == 0 )
 		return;
@@ -1195,7 +1201,6 @@ void MDWSlider::showContextMenu()
 		menu->addAction( b );
 	}
 
-	QPoint pos = QCursor::pos();
 	menu->popup( pos );
 }
 
@@ -1242,6 +1247,10 @@ bool MDWSlider::eventFilter( QObject* obj, QEvent* e )
 			showContextMenu();
 			return true;
 		}
+	} else if (eventType == QEvent::ContextMenu) {
+		QPoint pos = reinterpret_cast<QWidget *>(obj)->mapToGlobal(QPoint(0, 0));
+		showContextMenu(pos);
+		return true;
 	}
 	// Attention: We don't filter WheelEvents for KSmallSlider, because it handles WheelEvents itself
 	else if ( eventType == QEvent::Wheel )
