@@ -102,7 +102,7 @@ void MixDeviceWidget::setDisabled( bool ) { /* is virtual */ }
 //void MixDeviceWidget::setVolume( int /*channel*/, int /*vol*/ ) { /* is virtual */ }
 //void MixDeviceWidget::setVolume( Volume /*vol*/ ) { /* is virtual */ }
 void MixDeviceWidget::update() { /* is virtual */ }
-void MixDeviceWidget::showContextMenu() { /* is virtual */ }
+void MixDeviceWidget::showContextMenu( const QPoint &pos ) { /* is virtual */ }
 void MixDeviceWidget::setColors( QColor , QColor , QColor ) { /* is virtual */ }
 void MixDeviceWidget::setIcons( bool ) { /* is virtual */ }
 void MixDeviceWidget::setLabeled( bool ) { /* is virtual */ }
